V1PlateWriter
=============

.. currentmodule:: wwt_data_formats.plate

.. autoclass:: V1PlateWriter
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~V1PlateWriter.append_bytes
      ~V1PlateWriter.append_stream
      ~V1PlateWriter.close

   .. rubric:: Methods Documentation

   .. automethod:: append_bytes
   .. automethod:: append_stream
   .. automethod:: close
